@@ -1,6 +1,6 @@
-/* upnp.h - Generic UPnP handling definitions
+/* upnp.h - Generic UPnP definitions
  *
- * Copyright (C) 2005   Ivo Clarysse
+ * Copyright (C) 2005-2007   Ivo Clarysse
  *
  * This file is part of GMediaRender.
  *
@@ -61,9 +61,9 @@ typedef enum {
 } param_event;
 
 struct param_range {
-        int min;
-        int max;
-        int step;
+        long long min;
+        long long max;
+        long long step;
 };
 
 struct var_meta {
@@ -71,6 +71,7 @@ struct var_meta {
         param_datatype  datatype;
         const char      **allowed_values;
         struct param_range      *allowed_range;
+	const char      *default_value;
 };
 
 
@@ -83,6 +84,8 @@ struct icon {
 };
 
 struct device {
+	ithread_mutex_t device_mutex;
+	int (*init_function) (void);
         const char *device_type;
         const char *friendly_name;
         const char *manufacturer;
@@ -100,6 +103,7 @@ struct device {
 };
 
 struct service {
+	ithread_mutex_t *service_mutex;
 	const char *service_name;
 	char *type;
 	const char *scpd_url;
@@ -112,7 +116,6 @@ struct service {
 	struct var_meta *variable_meta;
 	int variable_count;
 	int command_count;
-	ithread_mutex_t *service_mutex;
 	const char **eventvar_names;
 	const char **eventvar_values;
 };
@@ -123,22 +126,12 @@ struct action_event {
 	struct service *service;
 };
 
-extern int init_upnp(struct device *device_def);
-
-
-
-extern int upnp_add_response(struct action_event *event, char *key,
-			     const char *value);
-extern void upnp_set_error(struct action_event *event, int error_code,
-			   const char *format, ...);
-extern char *upnp_get_string(struct action_event *event, const char *key);
-int upnp_append_variable(struct action_event *event,
-			 int varnum, char *paramname);
-
-extern IXML_Document *generate_scpd(struct service *srv);
-extern IXML_Document *generate_desc(void);
-
-extern UpnpDevice_Handle device_handle;
+struct service *find_service(struct device *device_def,
+                             char *service_name);
+struct action *find_action(struct service *event_service,
+                                  char *action_name);
 
+char *upnp_get_scpd(struct service *srv);
+char *upnp_get_device_desc(struct device *device_def);
 
 #endif /* _UPNP_H */
