@@ -1,6 +1,6 @@
 /* upnp_control.c - UPnP RenderingControl routines
  *
- * Copyright (C) 2005-2006   Ivo Clarysse
+ * Copyright (C) 2005-2007   Ivo Clarysse
  *
  * This file is part of GMediaRender.
  *
@@ -35,6 +35,7 @@
 #include "webserver.h"
 #include "upnp.h"
 #include "upnp_control.h"
+#include "upnp_device.h"
 
 //#define CONTROL_SERVICE "urn:upnp-org:serviceId:RenderingControl"
 #define CONTROL_SERVICE "urn:schemas-upnp-org:service:RenderingControl"
@@ -45,67 +46,67 @@
 
 
 typedef enum {
-	CONTROL_VAR_LAST_CHANGE,
-	CONTROL_VAR_PRESET_NAME_LIST,
-	CONTROL_VAR_AAT_CHANNEL,
-	CONTROL_VAR_AAT_INSTANCE_ID,
-	CONTROL_VAR_AAT_PRESET_NAME,
-	CONTROL_VAR_BRIGHTNESS,
-	CONTROL_VAR_CONTRAST,
-	CONTROL_VAR_SHARPNESS,
-	CONTROL_VAR_R_GAIN,
 	CONTROL_VAR_G_GAIN,
-	CONTROL_VAR_B_GAIN,
-	CONTROL_VAR_R_BLACK,
-	CONTROL_VAR_G_BLACK,
 	CONTROL_VAR_B_BLACK,
-	CONTROL_VAR_COLOR_TEMP,
-	CONTROL_VAR_HOR_KEYSTONE,
 	CONTROL_VAR_VER_KEYSTONE,
-	CONTROL_VAR_MUTE,
+	CONTROL_VAR_G_BLACK,
 	CONTROL_VAR_VOLUME,
-	CONTROL_VAR_VOLUME_DB,
 	CONTROL_VAR_LOUDNESS,
+	CONTROL_VAR_AAT_INSTANCE_ID,
+	CONTROL_VAR_R_GAIN,
+	CONTROL_VAR_COLOR_TEMP,
+	CONTROL_VAR_SHARPNESS,
+	CONTROL_VAR_AAT_PRESET_NAME,
+	CONTROL_VAR_R_BLACK,
+	CONTROL_VAR_B_GAIN,
+	CONTROL_VAR_MUTE,
+	CONTROL_VAR_LAST_CHANGE,
+	CONTROL_VAR_AAT_CHANNEL,
+	CONTROL_VAR_HOR_KEYSTONE,
+	CONTROL_VAR_VOLUME_DB,
+	CONTROL_VAR_PRESET_NAME_LIST,
+	CONTROL_VAR_CONTRAST,
+	CONTROL_VAR_BRIGHTNESS,
 	CONTROL_VAR_UNKNOWN,
 	CONTROL_VAR_COUNT
 } control_variable;
 
 typedef enum {
+	CONTROL_CMD_GET_BLUE_BLACK,
+	CONTROL_CMD_GET_BLUE_GAIN,
+	CONTROL_CMD_GET_BRIGHTNESS,
+	CONTROL_CMD_GET_COLOR_TEMP,
+	CONTROL_CMD_GET_CONTRAST,
+	CONTROL_CMD_GET_GREEN_BLACK,
+	CONTROL_CMD_GET_GREEN_GAIN,
+	CONTROL_CMD_GET_HOR_KEYSTONE,
+	CONTROL_CMD_GET_LOUDNESS,
+	CONTROL_CMD_GET_MUTE,
+	CONTROL_CMD_GET_RED_BLACK,
+	CONTROL_CMD_GET_RED_GAIN,
+	CONTROL_CMD_GET_SHARPNESS,
+	CONTROL_CMD_GET_VERT_KEYSTONE,
+	CONTROL_CMD_GET_VOL,
+	CONTROL_CMD_GET_VOL_DB,
+	CONTROL_CMD_GET_VOL_DBRANGE,
 	CONTROL_CMD_LIST_PRESETS,      
 	CONTROL_CMD_SELECT_PRESET,
-	CONTROL_CMD_GET_BRIGHTNESS,
-	CONTROL_CMD_SET_BRIGHTNESS,
-	CONTROL_CMD_GET_CONTRAST,
-	CONTROL_CMD_SET_CONTRAST,
-	CONTROL_CMD_GET_SHARPNESS,
-	CONTROL_CMD_SET_SHARPNESS,
-	CONTROL_CMD_GET_RED_GAIN,
-	CONTROL_CMD_SET_RED_GAIN,
-	CONTROL_CMD_GET_GREEN_GAIN,
-	CONTROL_CMD_SET_GREEN_GAIN,
-	CONTROL_CMD_GET_BLUE_GAIN,
-	CONTROL_CMD_SET_BLUE_GAIN,
-	CONTROL_CMD_GET_RED_BLACK,
-	CONTROL_CMD_SET_RED_BLACK,
-	CONTROL_CMD_GET_GREEN_BLACK,
-	CONTROL_CMD_SET_GREEN_BLACK,
-	CONTROL_CMD_GET_BLUE_BLACK,
 	CONTROL_CMD_SET_BLUE_BLACK,
-	CONTROL_CMD_GET_COLOR_TEMP,
+	CONTROL_CMD_SET_BLUE_GAIN,
+	CONTROL_CMD_SET_BRIGHTNESS,
 	CONTROL_CMD_SET_COLOR_TEMP,
-	CONTROL_CMD_GET_HOR_KEYSTONE,
+	CONTROL_CMD_SET_CONTRAST,
+	CONTROL_CMD_SET_GREEN_BLACK,
+	CONTROL_CMD_SET_GREEN_GAIN,
 	CONTROL_CMD_SET_HOR_KEYSTONE,
-	CONTROL_CMD_GET_VERT_KEYSTONE,
-	CONTROL_CMD_SET_VERT_KEYSTONE,
-	CONTROL_CMD_GET_MUTE,
-	CONTROL_CMD_SET_MUTE,
-	CONTROL_CMD_GET_VOL,
-	CONTROL_CMD_SET_VOL,
-	CONTROL_CMD_GET_VOL_DB,
-	CONTROL_CMD_SET_VOL_DB,
-	CONTROL_CMD_GET_VOL_DBRANGE,
-	CONTROL_CMD_GET_LOUDNESS,
 	CONTROL_CMD_SET_LOUDNESS,       
+	CONTROL_CMD_SET_MUTE,
+	CONTROL_CMD_SET_RED_BLACK,
+	CONTROL_CMD_SET_RED_GAIN,
+	CONTROL_CMD_SET_SHARPNESS,
+	CONTROL_CMD_SET_VERT_KEYSTONE,
+	CONTROL_CMD_SET_VOL,
+	CONTROL_CMD_SET_VOL_DB,
 	CONTROL_CMD_UNKNOWN,
 	CONTROL_CMD_COUNT
 } control_cmd;
@@ -141,6 +142,7 @@ static const char *aat_presetnames[] =
 {
 	"FactoryDefaults",
 	"InstallationDefaults",
+	"Vendor defined",
 	NULL
 };
 
@@ -149,29 +151,29 @@ static const char *aat_channels[] =
 	"Master",
 	"LF",
 	"RF",
-	"CF",
-	"LFE",
-	"LS",
-	"RS",
-	"LFC",
-	"RFC",
-	"SD",
-	"SL",
-	"SR",
-	"T",
-	"B",
+	//"CF",
+	//"LFE",
+	//"LS",
+	//"RS",
+	//"LFC",
+	//"RFC",
+	//"SD",
+	//"SL",
+	//"SR",
+	//"T",
+	//"B",
 	NULL
 };
 
-static struct param_range brightness_range = { 0, 255, 1 };
-static struct param_range contrast_range = { 0, 255, 1 };
-static struct param_range sharpness_range = { 0, 255, 1 };
-static struct param_range vid_gain_range = { 0, 255, 1 };
-static struct param_range vid_black_range = { 0, 255, 1 };
-static struct param_range colortemp_range = { 0, 255, 1 };
-static struct param_range keystone_range = { -128, 127, 1 };
-static struct param_range volume_range = { 0, 255, 1 };
-static struct param_range volume_db_range = { 0, 127, 1 };
+static struct param_range brightness_range = { 0, 100, 1 };
+static struct param_range contrast_range = { 0, 100, 1 };
+static struct param_range sharpness_range = { 0, 100, 1 };
+static struct param_range vid_gain_range = { 0, 100, 1 };
+static struct param_range vid_black_range = { 0, 100, 1 };
+static struct param_range colortemp_range = { 0, 65535, 1 };
+static struct param_range keystone_range = { -32768, 32767, 1 };
+static struct param_range volume_range = { 0, 100, 1 };
+static struct param_range volume_db_range = { -32768, 32767, 0 };
 
 static struct var_meta control_var_meta[] = {
 	[CONTROL_VAR_LAST_CHANGE] =		{ SENDEVENT_YES, DATATYPE_STRING, NULL, NULL },
