@@ -1,6 +1,6 @@
 /* upnp_renderer.h - UPnP renderer definitions
  *
- * Copyright (C) 2005   Ivo Clarysse
+ * Copyright (C) 2005-2007   Ivo Clarysse
  *
  * This file is part of GMediaRender.
  *
@@ -24,6 +24,11 @@
 #ifndef _UPNP_RENDERER_H
 #define _UPNP_RENDERER_H
 
-extern int init_upnp_renderer(void);
+void upnp_renderer_dump_connmgr_scpd(void);
+void upnp_renderer_dump_control_scpd(void);
+void upnp_renderer_dump_transport_scpd(void);
+
+struct device *upnp_renderer_new(const char *friendly_name,
+                                 const char *uuid);
 
 #endif /* _UPNP_RENDERER_H */
