@@ -1,6 +1,6 @@
 /* upnp_transport.c - UPnP AVTransport routines
  *
- * Copyright (C) 2005-2006   Ivo Clarysse
+ * Copyright (C) 2005-2007   Ivo Clarysse
  *
  * This file is part of GMediaRender.
  *
@@ -39,7 +39,9 @@
 
 #include "logging.h"
 
+#include "xmlescape.h"
 #include "upnp.h"
+#include "upnp_device.h"
 #include "upnp_transport.h"
 #include "output_gstreamer.h"
 
@@ -52,58 +54,59 @@
 
 
 typedef enum {
-	TRANSPORT_VAR_TRANSPORT_STATE,
 	TRANSPORT_VAR_TRANSPORT_STATUS,
+	TRANSPORT_VAR_NEXT_AV_URI,
+	TRANSPORT_VAR_NEXT_AV_URI_META,
+	TRANSPORT_VAR_CUR_TRACK_META,
+	TRANSPORT_VAR_REL_CTR_POS,
+	TRANSPORT_VAR_AAT_INSTANCE_ID,
+	TRANSPORT_VAR_AAT_SEEK_TARGET,
 	TRANSPORT_VAR_PLAY_MEDIUM,
-	TRANSPORT_VAR_REC_MEDIUM,
-	TRANSPORT_VAR_PLAY_MEDIA,
+	TRANSPORT_VAR_REL_TIME_POS,
 	TRANSPORT_VAR_REC_MEDIA,
 	TRANSPORT_VAR_CUR_PLAY_MODE,
 	TRANSPORT_VAR_TRANSPORT_PLAY_SPEED,
-	TRANSPORT_VAR_REC_MEDIUM_WR_STATUS,
-	TRANSPORT_VAR_CUR_REC_QUAL_MODE,
-	TRANSPORT_VAR_POS_REC_QUAL_MODE,
-	TRANSPORT_VAR_NR_TRACKS,
-	TRANSPORT_VAR_CUR_TRACK,
-	TRANSPORT_VAR_CUR_TRACK_DUR,
-	TRANSPORT_VAR_CUR_MEDIA_DUR,
-	TRANSPORT_VAR_CUR_TRACK_META,
-	TRANSPORT_VAR_CUR_TRACK_URI,
-	TRANSPORT_VAR_AV_URI,
-	TRANSPORT_VAR_AV_URI_META,
-	TRANSPORT_VAR_NEXT_AV_URI,
-	TRANSPORT_VAR_NEXT_AV_URI_META,
-	TRANSPORT_VAR_REL_TIME_POS,
+	TRANSPORT_VAR_PLAY_MEDIA,
 	TRANSPORT_VAR_ABS_TIME_POS,
-	TRANSPORT_VAR_REL_CTR_POS,
-	TRANSPORT_VAR_ABS_CTR_POS,
-	TRANSPORT_VAR_LAST_CHANGE,
-	TRANSPORT_VAR_AAT_SEEK_MODE,
-	TRANSPORT_VAR_AAT_SEEK_TARGET,
-	TRANSPORT_VAR_AAT_INSTANCE_ID,
+	TRANSPORT_VAR_CUR_TRACK,
+	TRANSPORT_VAR_CUR_TRACK_URI,
 	TRANSPORT_VAR_CUR_TRANSPORT_ACTIONS,
+	TRANSPORT_VAR_NR_TRACKS,
+	TRANSPORT_VAR_AV_URI,
+	TRANSPORT_VAR_ABS_CTR_POS,
+	TRANSPORT_VAR_CUR_REC_QUAL_MODE,
+	TRANSPORT_VAR_CUR_MEDIA_DUR,
+	TRANSPORT_VAR_AAT_SEEK_MODE,
+	TRANSPORT_VAR_AV_URI_META,
+	TRANSPORT_VAR_REC_MEDIUM,
+
+	TRANSPORT_VAR_REC_MEDIUM_WR_STATUS,
+	TRANSPORT_VAR_LAST_CHANGE,
+	TRANSPORT_VAR_CUR_TRACK_DUR,
+	TRANSPORT_VAR_TRANSPORT_STATE,
+	TRANSPORT_VAR_POS_REC_QUAL_MODE,
 	TRANSPORT_VAR_UNKNOWN,
 	TRANSPORT_VAR_COUNT
 } transport_variable;
 
 typedef enum {
-	TRANSPORT_CMD_SETAVTRANSPORTURI,             
-	TRANSPORT_CMD_SETNEXTAVTRANSPORTURI,
-	TRANSPORT_CMD_GETMEDIAINFO,
-	TRANSPORT_CMD_GETTRANSPORTINFO,
-	TRANSPORT_CMD_GETPOSITIONINFO,
-	TRANSPORT_CMD_GETDEVICECAPABILITIES,
-	TRANSPORT_CMD_GETTRANSPORTSETTINGS,
-	TRANSPORT_CMD_STOP,
-	TRANSPORT_CMD_PLAY,
-	TRANSPORT_CMD_PAUSE,
-	TRANSPORT_CMD_RECORD,
-	TRANSPORT_CMD_SEEK,
-	TRANSPORT_CMD_NEXT,
-	TRANSPORT_CMD_PREVIOUS,
-	TRANSPORT_CMD_SETPLAYMODE,
-	TRANSPORT_CMD_SETRECORDQUALITYMODE,
 	TRANSPORT_CMD_GETCURRENTTRANSPORTACTIONS,
+	TRANSPORT_CMD_GETDEVICECAPABILITIES,
+	TRANSPORT_CMD_GETMEDIAINFO,
+	TRANSPORT_CMD_GETPOSITIONINFO,
+	TRANSPORT_CMD_GETTRANSPORTINFO,
+	TRANSPORT_CMD_GETTRANSPORTSETTINGS,
+	TRANSPORT_CMD_NEXT,
+	TRANSPORT_CMD_PAUSE,
+	TRANSPORT_CMD_PLAY,
+	TRANSPORT_CMD_PREVIOUS,
+	TRANSPORT_CMD_SEEK,
+	TRANSPORT_CMD_SETAVTRANSPORTURI,             
+	TRANSPORT_CMD_SETPLAYMODE,
+	TRANSPORT_CMD_STOP,
+	//TRANSPORT_CMD_SETNEXTAVTRANSPORTURI,
+	//TRANSPORT_CMD_RECORD,
+	//TRANSPORT_CMD_SETRECORDQUALITYMODE,
 	TRANSPORT_CMD_UNKNOWN,                   
 	TRANSPORT_CMD_COUNT
 } transport_cmd ;
@@ -168,7 +171,7 @@ static char *transport_values[] = {
 	[TRANSPORT_VAR_ABS_TIME_POS] = "NOT_IMPLEMENTED",
 	[TRANSPORT_VAR_REL_CTR_POS] = "2147483647",
 	[TRANSPORT_VAR_ABS_CTR_POS] = "2147483647",
-        [TRANSPORT_VAR_LAST_CHANGE] = "<Event xmlns = \"urn:schemas-upnp-org:metadata-1-0/AVT/\"><InstanceID val=\"0\"></InstanceID></Event>",
+        [TRANSPORT_VAR_LAST_CHANGE] = "<Event xmlns=\"urn:schemas-upnp-org:metadata-1-0/AVT/\"/>",
 
 	[TRANSPORT_VAR_AAT_SEEK_MODE] = "TRACK_NR",
 	[TRANSPORT_VAR_AAT_SEEK_TARGET] = "",
@@ -190,6 +193,7 @@ static const char *transport_states[] = {
 static const char *transport_stati[] = {
 	"OK",
 	"ERROR_OCCURRED",
+	" vendor-defined ",
 	NULL
 };
 static const char *media[] = {
@@ -225,22 +229,24 @@ static const char *media[] = {
 	"NETWORK",
 	"NONE",
 	"NOT_IMPLEMENTED",
+	" vendor-defined ",
 	NULL
 };
 
 static const char *playmodi[] = {
 	"NORMAL",
-	"SHUFFLE",
-	"REPEAT_ONE",
+	//"SHUFFLE",
+	//"REPEAT_ONE",
 	"REPEAT_ALL",
-	"RANDOM",
-	"DIRECT_1",
+	//"RANDOM",
+	//"DIRECT_1",
 	"INTRO",
 	NULL
 };
 
 static const char *playspeeds[] = {
 	"1",
+	" vendor-defined ",
 	NULL
 };
 
@@ -261,6 +267,7 @@ static const char *rec_quality_modi[] = {
 	"1:MEDIUM",
 	"2:HIGH",
 	"NOT_IMPLEMENTED",
+	" vendor-defined ",
 	NULL
 };
 
@@ -276,7 +283,17 @@ static const char *aat_seekmodi[] = {
 	NULL
 };
 
-static struct param_range track_range = { 0, 255, 1 };
+static struct param_range track_range = {
+	0,
+	4294967295LL,
+	1
+};
+
+static struct param_range track_nr_range = {
+	0,
+	4294967295LL,
+	0
+};
 
 static struct var_meta transport_var_meta[] = {
 	[TRANSPORT_VAR_TRANSPORT_STATE] =		{ SENDEVENT_NO, DATATYPE_STRING, transport_states, NULL },
@@ -285,12 +302,12 @@ static struct var_meta transport_var_meta[] = {
 	[TRANSPORT_VAR_REC_MEDIUM] =			{ SENDEVENT_NO, DATATYPE_STRING, media, NULL },
 	[TRANSPORT_VAR_PLAY_MEDIA] =			{ SENDEVENT_NO, DATATYPE_STRING, NULL, NULL },
 	[TRANSPORT_VAR_REC_MEDIA] =			{ SENDEVENT_NO, DATATYPE_STRING, NULL, NULL },
-	[TRANSPORT_VAR_CUR_PLAY_MODE] =			{ SENDEVENT_NO, DATATYPE_STRING, playmodi, NULL },
+	[TRANSPORT_VAR_CUR_PLAY_MODE] =			{ SENDEVENT_NO, DATATYPE_STRING, playmodi, NULL, "NORMAL" },
 	[TRANSPORT_VAR_TRANSPORT_PLAY_SPEED] =		{ SENDEVENT_NO, DATATYPE_STRING, playspeeds, NULL },
 	[TRANSPORT_VAR_REC_MEDIUM_WR_STATUS] =		{ SENDEVENT_NO, DATATYPE_STRING, rec_write_stati, NULL },
 	[TRANSPORT_VAR_CUR_REC_QUAL_MODE] =		{ SENDEVENT_NO, DATATYPE_STRING, rec_quality_modi, NULL },
 	[TRANSPORT_VAR_POS_REC_QUAL_MODE] =		{ SENDEVENT_NO, DATATYPE_STRING, NULL, NULL },
-	[TRANSPORT_VAR_NR_TRACKS] =			{ SENDEVENT_NO, DATATYPE_UI4, NULL, &track_range }, /* no step */
+	[TRANSPORT_VAR_NR_TRACKS] =			{ SENDEVENT_NO, DATATYPE_UI4, NULL, &track_nr_range }, /* no step */
 	[TRANSPORT_VAR_CUR_TRACK] =			{ SENDEVENT_NO, DATATYPE_UI4, NULL, &track_range },
 	[TRANSPORT_VAR_CUR_TRACK_DUR] =			{ SENDEVENT_NO, DATATYPE_STRING, NULL, NULL },
 	[TRANSPORT_VAR_CUR_MEDIA_DUR] =			{ SENDEVENT_NO, DATATYPE_STRING, NULL, NULL },
@@ -319,17 +336,17 @@ static struct argument *arguments_setavtransporturi[] = {
         NULL
 };
 
-static struct argument *arguments_setnextavtransporturi[] = {
-        & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
-        & (struct argument) { "NextURI", PARAM_DIR_IN, TRANSPORT_VAR_NEXT_AV_URI },
-        & (struct argument) { "NextURIMetaData", PARAM_DIR_IN, TRANSPORT_VAR_NEXT_AV_URI_META },
-        NULL
-};
+//static struct argument *arguments_setnextavtransporturi[] = {
+//        & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
+//        & (struct argument) { "NextURI", PARAM_DIR_IN, TRANSPORT_VAR_NEXT_AV_URI },
+//        & (struct argument) { "NextURIMetaData", PARAM_DIR_IN, TRANSPORT_VAR_NEXT_AV_URI_META },
+//        NULL
+//};
 
 static struct argument *arguments_getmediainfo[] = {
         & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
         & (struct argument) { "NrTracks", PARAM_DIR_OUT, TRANSPORT_VAR_NR_TRACKS },
-        & (struct argument) { "MediaDuraction", PARAM_DIR_OUT, TRANSPORT_VAR_CUR_MEDIA_DUR },
+        & (struct argument) { "MediaDuration", PARAM_DIR_OUT, TRANSPORT_VAR_CUR_MEDIA_DUR },
         & (struct argument) { "CurrentURI", PARAM_DIR_OUT, TRANSPORT_VAR_AV_URI },
         & (struct argument) { "CurrentURIMetaData", PARAM_DIR_OUT, TRANSPORT_VAR_AV_URI_META },
         & (struct argument) { "NextURI", PARAM_DIR_OUT, TRANSPORT_VAR_NEXT_AV_URI },
@@ -389,10 +406,10 @@ static struct argument *arguments_pause[] = {
         & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
 	NULL
 };
-static struct argument *arguments_record[] = {
-        & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
-	NULL
-};
+//static struct argument *arguments_record[] = {
+//        & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
+//	NULL
+//};
 
 static struct argument *arguments_seek[] = {
         & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
@@ -413,11 +430,11 @@ static struct argument *arguments_setplaymode[] = {
         & (struct argument) { "NewPlayMode", PARAM_DIR_IN, TRANSPORT_VAR_CUR_PLAY_MODE },
 	NULL
 };
-static struct argument *arguments_setrecordqualitymode[] = {
-        & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
-        & (struct argument) { "NewRecordQualityMode", PARAM_DIR_IN, TRANSPORT_VAR_CUR_REC_QUAL_MODE },
-	NULL
-};
+//static struct argument *arguments_setrecordqualitymode[] = {
+//        & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
+//        & (struct argument) { "NewRecordQualityMode", PARAM_DIR_IN, TRANSPORT_VAR_CUR_REC_QUAL_MODE },
+//	NULL
+//};
 static struct argument *arguments_getcurrenttransportactions[] = {
         & (struct argument) { "InstanceID", PARAM_DIR_IN, TRANSPORT_VAR_AAT_INSTANCE_ID },
         & (struct argument) { "Actions", PARAM_DIR_OUT, TRANSPORT_VAR_CUR_TRANSPORT_ACTIONS },
@@ -427,21 +444,21 @@ static struct argument *arguments_getcurrenttransportactions[] = {
 
 static struct argument **argument_list[] = {
 	[TRANSPORT_CMD_SETAVTRANSPORTURI] =         arguments_setavtransporturi,
-	[TRANSPORT_CMD_SETNEXTAVTRANSPORTURI] =     arguments_setnextavtransporturi,
+	[TRANSPORT_CMD_GETDEVICECAPABILITIES] =     arguments_getdevicecapabilities,
 	[TRANSPORT_CMD_GETMEDIAINFO] =              arguments_getmediainfo,
+	//[TRANSPORT_CMD_SETNEXTAVTRANSPORTURI] =     arguments_setnextavtransporturi,
 	[TRANSPORT_CMD_GETTRANSPORTINFO] =          arguments_gettransportinfo,
 	[TRANSPORT_CMD_GETPOSITIONINFO] =           arguments_getpositioninfo,
-	[TRANSPORT_CMD_GETDEVICECAPABILITIES] =     arguments_getdevicecapabilities,
 	[TRANSPORT_CMD_GETTRANSPORTSETTINGS] =      arguments_gettransportsettings,
 	[TRANSPORT_CMD_STOP] =                      arguments_stop,
 	[TRANSPORT_CMD_PLAY] =                      arguments_play,
 	[TRANSPORT_CMD_PAUSE] =                     arguments_pause,
-	[TRANSPORT_CMD_RECORD] =                    arguments_record,
+	//[TRANSPORT_CMD_RECORD] =                    arguments_record,
 	[TRANSPORT_CMD_SEEK] =                      arguments_seek,
 	[TRANSPORT_CMD_NEXT] =                      arguments_next,
 	[TRANSPORT_CMD_PREVIOUS] =                  arguments_previous,
 	[TRANSPORT_CMD_SETPLAYMODE] =               arguments_setplaymode,
-	[TRANSPORT_CMD_SETRECORDQUALITYMODE] =      arguments_setrecordqualitymode,
+	//[TRANSPORT_CMD_SETRECORDQUALITYMODE] =      arguments_setrecordqualitymode,
 	[TRANSPORT_CMD_GETCURRENTTRANSPORTACTIONS] = arguments_getcurrenttransportactions,
 	[TRANSPORT_CMD_UNKNOWN] =	NULL
 };
@@ -528,63 +545,6 @@ static int get_media_info(struct action_event *event)
 	return rc;
 }
 
-static void sgmlattrescape(const char *str, char *target, uint32_t * length)
-{
-	if (target != NULL) {
-		uint32_t len = 0;
-
-		for (; *str; str++) {
-			if (*str == '<') {
-				memcpy(target + len, "&lt;", 4);
-				len += 4;
-			} else if (*str == '"') {
-				memcpy(target + len, "%22", 3);
-				len += 3;
-			} else if (*str == '>') {
-				memcpy(target + len, "&gt;", 4);
-				len += 4;
-			} else if (*str == '&') {
-				memcpy(target + len, "&amp;", 5);
-				len += 5;
-			} else {
-				target[len++] = *str;
-			}
-		}
-		target[len] = '\0';
-
-		if (length != NULL)
-			*length = len;
-	} else if (length != NULL) {
-		uint32_t len = 0;
-
-		for (; *str; str++) {
-			if (*str == '<') {
-				len += 4;
-			} else if (*str == '"') {
-				len += 3;
-			} else if (*str == '>') {
-				len += 4;
-			} else if (*str == '&') {
-				len += 5;
-			} else {
-				len++;
-			}
-		}
-
-		*length = len;
-	}
-}
-
-static char *xsgmlattrescape(const char *str)
-{
-	uint32_t len;
-	char *out;
-
-	sgmlattrescape(str, NULL, &len);
-	out = malloc(len + 1);
-	sgmlattrescape(str, out, NULL);
-	return out;
-}
 
 static void notify_lastchange(struct action_event *event, char *value)
 {
@@ -598,7 +558,6 @@ static void notify_lastchange(struct action_event *event, char *value)
 
 
 	printf("Event: '%s'\n", value);
-	//varvalues[0] = xsgmlescape(value);
 	varvalues[0] = value;
 
 
@@ -606,8 +565,6 @@ static void notify_lastchange(struct action_event *event, char *value)
 	UpnpNotify(device_handle, event->request->DevUDN,
 		   event->request->ServiceID, varnames,
 		   (const char **) varvalues, 1);
-
-	//free(varvalues[0]);
 }
 
 /* warning - does not lock service mutex */
@@ -633,9 +590,9 @@ static void change_var(struct action_event *event, int varnum,
 	transport_values[varnum] = strdup(new_value);
 	asprintf(&buf,
 		 "<Event xmlns = \"urn:schemas-upnp-org:metadata-1-0/AVT/\"><InstanceID val=\"0\"><%s val=\"%s\"/></InstanceID></Event>",
-		 transport_variables[varnum], xsgmlattrescape(transport_values[varnum]));
+		 transport_variables[varnum], xmlescape(transport_values[varnum], 1));
 	notify_lastchange(event, buf);
-	//free(buf)
+	free(buf);
 
 	LEAVE();
 
@@ -710,34 +667,34 @@ static int set_avtransport_uri(struct action_event *event)
 	return rc;
 }
 
-static int set_next_avtransport_uri(struct action_event *event)
-{
-	char *value;
-
-	ENTER();
-
-	if (obtain_instanceid(event, NULL)) {
-		LEAVE();
-		return -1;
-	}
-	value = upnp_get_string(event, "NextURI");
-	if (value == NULL) {
-		LEAVE();
-		return -1;
-	}
-	printf("%s: NextURI='%s'\n", __FUNCTION__, value);
-	free(value);
-	value = upnp_get_string(event, "NextURIMetaData");
-	if (value == NULL) {
-		LEAVE();
-		return -1;
-	}
-	printf("%s: NextURIMetaData='%s'\n", __FUNCTION__, value);
-	free(value);
-
-	LEAVE();
-	return 0;
-}
+//static int set_next_avtransport_uri(struct action_event *event)
+//{
+//	char *value;
+//
+//	ENTER();
+//
+//	if (obtain_instanceid(event, NULL)) {
+//		LEAVE();
+//		return -1;
+//	}
+//	value = upnp_get_string(event, "NextURI");
+//	if (value == NULL) {
+//		LEAVE();
+//		return -1;
+//	}
+//	printf("%s: NextURI='%s'\n", __FUNCTION__, value);
+//	free(value);
+//	value = upnp_get_string(event, "NextURIMetaData");
+//	if (value == NULL) {
+//		LEAVE();
+//		return -1;
+//	}
+//	printf("%s: NextURIMetaData='%s'\n", __FUNCTION__, value);
+//	free(value);
+//
+//	LEAVE();
+//	return 0;
+//}
 
 static int get_transport_info(struct action_event *event)
 {
@@ -985,23 +942,23 @@ static int previous(struct action_event *event)
 
 
 static struct action transport_actions[] = {
-	[TRANSPORT_CMD_SETAVTRANSPORTURI] =         {"SetAVTransportURI", set_avtransport_uri},	/* RC9800i */
-	[TRANSPORT_CMD_SETNEXTAVTRANSPORTURI] =     {"SetNextAVTransportURI", set_next_avtransport_uri},
+	[TRANSPORT_CMD_GETCURRENTTRANSPORTACTIONS] = {"GetCurrentTransportActions", NULL},	/* optional */
+	[TRANSPORT_CMD_GETDEVICECAPABILITIES] =     {"GetDeviceCapabilities", get_device_caps},
 	[TRANSPORT_CMD_GETMEDIAINFO] =              {"GetMediaInfo", get_media_info},
+	[TRANSPORT_CMD_SETAVTRANSPORTURI] =         {"SetAVTransportURI", set_avtransport_uri},	/* RC9800i */
+	//[TRANSPORT_CMD_SETNEXTAVTRANSPORTURI] =     {"SetNextAVTransportURI", set_next_avtransport_uri},
 	[TRANSPORT_CMD_GETTRANSPORTINFO] =          {"GetTransportInfo", get_transport_info},
 	[TRANSPORT_CMD_GETPOSITIONINFO] =           {"GetPositionInfo", get_position_info},
-	[TRANSPORT_CMD_GETDEVICECAPABILITIES] =     {"GetDeviceCapabilities", get_device_caps},
 	[TRANSPORT_CMD_GETTRANSPORTSETTINGS] =      {"GetTransportSettings", get_transport_settings},
 	[TRANSPORT_CMD_STOP] =                      {"Stop", stop},
 	[TRANSPORT_CMD_PLAY] =                      {"Play", play},
 	[TRANSPORT_CMD_PAUSE] =                     {"Pause", NULL},	/* optional */
-	[TRANSPORT_CMD_RECORD] =                    {"Record", NULL},	/* optional */
+	//[TRANSPORT_CMD_RECORD] =                    {"Record", NULL},	/* optional */
 	[TRANSPORT_CMD_SEEK] =                      {"Seek", seek},
 	[TRANSPORT_CMD_NEXT] =                      {"Next", next},
 	[TRANSPORT_CMD_PREVIOUS] =                  {"Previous", previous},
 	[TRANSPORT_CMD_SETPLAYMODE] =               {"SetPlayMode", NULL},	/* optional */
-	[TRANSPORT_CMD_SETRECORDQUALITYMODE] =      {"SetRecordQualityMode", NULL},	/* optional */
-	[TRANSPORT_CMD_GETCURRENTTRANSPORTACTIONS] = {"GetCurrentTransportActions", NULL},	/* optional */
+	//[TRANSPORT_CMD_SETRECORDQUALITYMODE] =      {"SetRecordQualityMode", NULL},	/* optional */
 	[TRANSPORT_CMD_UNKNOWN] =                  {NULL, NULL}
 };
 
